@@ -2,16 +2,10 @@ from __future__ import with_statement
 from nose.tools import assert_raises
 
 from flask import Flask
-try:
-    from flask import Blueprint
-except ImportError:
-    # Blueprints only available starting with 0.7,
-    # fall back to old Modules otherwise.
-    Blueprint = None
-    from flask import Module
 from flaskext.assets import Environment, Bundle
 from webassets.bundle import get_all_bundle_files
-    
+from helpers import TempEnvironmentHelper, Module, Blueprint
+
 
 class TestUrlAndDirectory(object):
     """By default, the 'url' and 'directory' settings of webassets are
@@ -61,6 +55,10 @@ class TestUrlAndDirectory(object):
         # module name, you can always use this hack:
         assert get_all_bundle_files(Bundle('./module/bar'), self.env) == [root + '/static/module/bar']
 
+        # Custom static folder
+        self.app.static_folder = '/'
+        assert get_all_bundle_files(Bundle('foo'), self.env) == ['/foo']
+
     def test_directory_custom(self):
         """A custom root directory is configured."""
         self.env.directory = '/tmp'
@@ -127,3 +125,25 @@ class TestUrlAndDirectoryWithInitApp(object):
             root = self.app.root_path
             assert get_all_bundle_files(Bundle('foo'), self.env) == [root + '/static/foo']
 
+
+class TestBuild(TempEnvironmentHelper):
+    """[Regression]
+
+    Make sure actually building a bundle works also.
+    """
+
+    default_files = {
+        'foo': 'function bla  () { /* comment */ var a; }    ',
+    }
+
+    def test_build(self):
+        self.mkbundle('foo', filters='rjsmin', output='out').build()
+        assert self.get('out') == 'function bla(){var a;}'
+
+    def test_with_cache_default_directory(self):
+        """[Regression] The cache directory is created in the Flask
+        main static folder.
+        """
+        self.env.cache = True
+        self.mkbundle('foo', filters='rjsmin', output='out').build()
+        assert self.get('out') == 'function bla(){var a;}'
